pub struct ConvertChip;Trait Implementations
Sourceimpl<AB> Air<AB> for ConvertChipwhere
AB: SP1RecursionAirBuilder + PairBuilder,
impl<AB> Air<AB> for ConvertChipwhere
AB: SP1RecursionAirBuilder + PairBuilder,
Sourceimpl<F: Field> BaseAir<F> for ConvertChip
impl<F: Field> BaseAir<F> for ConvertChip
fn preprocessed_trace(&self) -> Option<DenseMatrix<F>>
Sourceimpl Clone for ConvertChip
impl Clone for ConvertChip
Sourcefn clone(&self) -> ConvertChip
fn clone(&self) -> ConvertChip
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ConvertChip
impl Default for ConvertChip
Sourcefn default() -> ConvertChip
fn default() -> ConvertChip
Returns the “default value” for a type. Read more
Sourceimpl<F: PrimeField32 + BinomiallyExtendable<D>> MachineAir<F> for ConvertChip
impl<F: PrimeField32 + BinomiallyExtendable<D>> MachineAir<F> for ConvertChip
Sourcetype Record = ExecutionRecord<F>
type Record = ExecutionRecord<F>
The execution record containing events for producing the air trace.
Sourcetype Program = RecursionProgram<F>
type Program = RecursionProgram<F>
The program that defines the control flow of the machine.
Sourcefn preprocessed_width(&self) -> usize
fn preprocessed_width(&self) -> usize
The width of the preprocessed trace.
Sourcefn preprocessed_num_rows(&self, program: &Self::Program) -> Option<usize>
fn preprocessed_num_rows(&self, program: &Self::Program) -> Option<usize>
The number of rows in the preprocessed trace
Sourcefn preprocessed_num_rows_with_instrs_len(
&self,
program: &Self::Program,
instrs_len: usize,
) -> Option<usize>
fn preprocessed_num_rows_with_instrs_len( &self, program: &Self::Program, instrs_len: usize, ) -> Option<usize>
The number of rows in the preprocessed trace using the program and the instr len.
Sourcefn generate_preprocessed_trace_into(
&self,
program: &Self::Program,
buffer: &mut [MaybeUninit<F>],
)
fn generate_preprocessed_trace_into( &self, program: &Self::Program, buffer: &mut [MaybeUninit<F>], )
Generate the preprocessed trace into a slice of
MaybeUninit<F>.Sourcefn generate_dependencies(&self, _: &Self::Record, _: &mut Self::Record)
fn generate_dependencies(&self, _: &Self::Record, _: &mut Self::Record)
Generate the dependencies for a given execution record.
Sourcefn num_rows(&self, input: &Self::Record) -> Option<usize>
fn num_rows(&self, input: &Self::Record) -> Option<usize>
The number of rows in the trace, if the chip is included. Read more
Sourcefn generate_trace_into(
&self,
input: &ExecutionRecord<F>,
_: &mut ExecutionRecord<F>,
buffer: &mut [MaybeUninit<F>],
)
fn generate_trace_into( &self, input: &ExecutionRecord<F>, _: &mut ExecutionRecord<F>, buffer: &mut [MaybeUninit<F>], )
Generate the trace into a slice of
MaybeUninit<F>.Sourcefn included(&self, _record: &Self::Record) -> bool
fn included(&self, _record: &Self::Record) -> bool
Whether this execution record contains events for this air.
Sourcefn generate_trace(
&self,
input: &Self::Record,
output: &mut Self::Record,
) -> DenseMatrix<F>
fn generate_trace( &self, input: &Self::Record, output: &mut Self::Record, ) -> DenseMatrix<F>
Generate the trace for a given execution record. Read more
Sourcefn generate_preprocessed_trace(
&self,
program: &Self::Program,
) -> Option<DenseMatrix<F>>
fn generate_preprocessed_trace( &self, program: &Self::Program, ) -> Option<DenseMatrix<F>>
Generate the preprocessed trace given a specific program.