pub async fn test_recursion_linear_program(instrs: Vec<Instruction<SP1Field>>)Expand description
Constructs a linear program and runs it on machines that use the wide and skinny Poseidon2 chips.
pub async fn test_recursion_linear_program(instrs: Vec<Instruction<SP1Field>>)Constructs a linear program and runs it on machines that use the wide and skinny Poseidon2 chips.